#!/bin/sh

OPL=/usr/local/bin/cplex-opl
AWK=/bin/gawk
cd $HOME/cplex
for PROV in BC AB SK MB ON QC PE NB NS NL
do
  echo "Optimizing ${PROV}"
  ${OPL} Election.mod Election-${PROV}.dat </dev/null >Election-${PROV}.log
  if [ -r Election2${PROV}.dat ]
  then
    ${OPL} Election.mod Election2${PROV}.dat </dev/null >Election2${PROV}.log
  else
    ${OPL} Election2.mod Election-${PROV}.dat </dev/null >Election2${PROV}.log
  fi
done
echo "Postprocessing"
${AWK} -v mode=1 '/^OBJECTIVE: / { optimum=0+$2;
  c=split(FILENAME,v,"/");
  province=substr(v[c],10,2);
  printf("%s,%d,%d\n",province,mode,optimum);
}' Election-??.log >Election.opt
${AWK} -v mode=2 '/^OBJECTIVE: / {
  c=split(FILENAME,v,"/");
  province=substr(v[c],10,2);
  optimum[province]+=$2;
  if (x[province]==0) list[x[province]= ++n]=province;
}
$2~/MAJORITY:/ {
  c=split(FILENAME,v,"/");
  province=substr(v[c],10,2);
  optimum[province]+=$4;
  if (x[province]==0) list[x[province]= ++n]=province;
}
END {
  for (i=1;i<=n;++i) {
    province=list[i];
    printf("%s,%d,%d\n",province,mode,optimum[province]);
  }
}' Election2??.log Election2??.dat >>Election.opt
${AWK} '/^ASSIGNED: / {
  c=split(FILENAME,v,"/");
  split(v[c],w,"-");
  province=substr(w[2],1,2);
  id=$2; party=$3; votes=$4;
  printf("%s,%s,%s,%d\n",province,id,party,votes);
}' Election-??.log >Election.csv
${AWK} '/ASSIGNED:/ {
  c=split(FILENAME,v,"/");
  province=substr(v[c],10,2);
  if ($1=="ASSIGNED:") { id=$2; pp=$3; vv=$4; }
  else if ($2=="ASSIGNED:") { id=$3; pp=$4; vv=$5; }
  else id="";
  if (id!="") {
    i=x[id]; if (i==0) { i= x[id]= ++n; list[n]=id; }
    j= ++r[i];
    party[i,j]=pp;
    votes[i,j]=vv;
    prov[i]=province;
  }
}
END {
  for (i=1;i<=n;++i) {
    id=list[i]; province=prov[i];
    v1=votes[i,1];
    v2=votes[i,2];
    if (v1>=v2) {
      senior_party=party[i,1];
      senior_votes=v1;
      junior_party=party[i,2];
      junior_votes=v2;
    }
    else {
      senior_party=party[i,2];
      senior_votes=v2;
      junior_party=party[i,1];
      junior_votes=v1;
    }
    printf("%s,%s,%s,%d,%s,%d\n",province,id,
      senior_party,senior_votes,
      junior_party,junior_votes);
  }
}' Election2??.log Election2??.dat >Election2.csv
echo "Done."
exit 0
